@@ -46,7 +46,7 @@ Glib::ustring GtkDialogs::ui_file_select_open()
   fileChooser_Open.hide();
   if(response_id != Gtk::RESPONSE_CANCEL)
   {
-    return fileChooser_Open.get_filename();
+    return fileChooser_Open.get_uri();
   }
   else
     return "";
@@ -68,7 +68,7 @@ Glib::ustring GtkDialogs::ui_file_select_save(const Glib::ustring& old_filepath)
   fileChooser_Save.hide();
   if(response_id != Gtk::RESPONSE_CANCEL)
   {
-    return fileChooser_Save.get_filename();
+    return fileChooser_Save.get_uri();
   }
   else
     return "";
